--
-- Name: gtfs; Type: SCHEMA; Schema: -; Owner: -
--

CREATE SCHEMA gtfs;

--
-- Name: wgs84_lat; Type: DOMAIN; Schema: gtfs; Owner: -
--

CREATE DOMAIN gtfs.wgs84_lat AS DECIMAL(10,7) CHECK(VALUE >= -90 AND VALUE <= 90);
CREATE DOMAIN gtfs.wgs84_lon AS DECIMAL(10,7) CHECK(VALUE >= -180 AND VALUE <= 180);

--
-- Name: gtfs_agency; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

SET DATABASE SQL SYNTAX PGS TRUE;

CREATE TABLE gtfs.gtfs_agency (
    agency_id text,
    agency_name text NOT NULL,
    agency_url text NOT NULL,
    agency_timezone text NOT NULL,
    agency_lang text,
    agency_phone text,
    agency_fare_url text
);


--
-- Name: gtfs_calendar; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_calendar (
    service_id text NOT NULL,
    monday boolean NOT NULL,
    tuesday boolean NOT NULL,
    wednesday boolean NOT NULL,
    thursday boolean NOT NULL,
    friday boolean NOT NULL,
    saturday boolean NOT NULL,
    sunday boolean NOT NULL,
    start_date date NOT NULL,
    end_date date NOT NULL
);


--
-- Name: gtfs_calendar_dates; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_calendar_dates (
    service_id text NOT NULL,
    date date NOT NULL,
    exception_type smallint NOT NULL,
    CONSTRAINT gtfs_calendar_dates_exception_type_check CHECK (((exception_type >= 1) AND (exception_type <= 2)))
);


--
-- Name: gtfs_fare_attributes; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_fare_attributes (
    fare_id text NOT NULL,
    price numeric(10,3) NOT NULL,
    currency_type character(3) NOT NULL,
    payment_method boolean NOT NULL,
    transfers smallint,
    transfer_duration integer
);


--
-- Name: gtfs_fare_rules; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_fare_rules (
    fare_id text NOT NULL,
    route_id text,
    origin_id text,
    destination_id text,
    contains_id text
);


--
-- Name: gtfs_feed_info; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_feed_info (
    feed_publisher_name text NOT NULL,
    feed_publisher_url text NOT NULL,
    feed_lang text NOT NULL,
    feed_start_date date,
    feed_end_date date,
    feed_version text
);


--
-- Name: gtfs_frequencies; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_frequencies (
    trip_id text NOT NULL,
    start_time character varying(8) NOT NULL,
    end_time character varying(8) NOT NULL,
    headway_secs integer NOT NULL,
    exact_times boolean
);


--
-- Name: gtfs_routes; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_routes (
    route_id text NOT NULL,
    agency_id text,
    route_short_name text NOT NULL,
    route_long_name text NOT NULL,
    route_desc text,
    route_type smallint NOT NULL,
    route_url text,
    route_color text,
    route_text_color text
);


--
-- Name: gtfs_shapes; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_shapes (
    shape_id text NOT NULL,
    shape_pt_lat gtfs.wgs84_lat NOT NULL,
    shape_pt_lon gtfs.wgs84_lon NOT NULL,
    shape_pt_sequence integer NOT NULL,
    shape_dist_traveled numeric(10,3)
);


--
-- Name: gtfs_stop_times; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_stop_times (
    trip_id text NOT NULL,
    arrival_time character varying(8) NOT NULL,
    departure_time character varying(8) NOT NULL,
    stop_id text NOT NULL,
    stop_sequence integer NOT NULL,
    stop_headsign text,
    pickup_type smallint,
    drop_off_type smallint,
    shape_dist_traveled numeric(10,3),
    CONSTRAINT gtfs_stop_times_drop_off_type_check CHECK (((drop_off_type >= 0) AND (drop_off_type <= 3))),
    CONSTRAINT gtfs_stop_times_pickup_type_check CHECK (((pickup_type >= 0) AND (pickup_type <= 3)))
);


--
-- Name: gtfs_stops; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_stops (
    stop_id text NOT NULL,
    stop_code text,
    stop_name text NOT NULL,
    stop_desc text,
    stop_lat gtfs.wgs84_lat NOT NULL,
    stop_lon gtfs.wgs84_lon NOT NULL,
    zone_id text,
    stop_url text,
    location_type boolean,
    parent_station text,
    stop_timezone text,
    wheelchair_boarding smallint,
    CONSTRAINT gtfs_stops_wheelchair_boarding_check CHECK (((wheelchair_boarding >= 0) AND (wheelchair_boarding <= 2)))
);


--
-- Name: gtfs_transfers; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_transfers (
    from_stop_id text NOT NULL,
    to_stop_id text NOT NULL,
    transfer_type smallint NOT NULL,
    min_transfer_time integer,
    CONSTRAINT gtfs_transfers_transfer_type_check CHECK (((transfer_type >= 0) AND (transfer_type <= 3)))
);


--
-- Name: gtfs_trips; Type: TABLE; Schema: gtfs; Owner: -; Tablespace: 
--

CREATE TABLE gtfs.gtfs_trips (
    route_id text NOT NULL,
    service_id text NOT NULL,
    trip_id text NOT NULL,
    trip_headsign text,
    trip_short_name text,
    direction_id boolean,
    block_id text,
    shape_id text
);

SET SCHEMA gtfs;
